@@ -13,8 +13,9 @@ from . import base as cvb
 from . import defaults as cvd
 from . import parameters as cvpar
 from . import population as cvpop
-from . import interventions as cvi
 from . import plotting as cvplt
+from . import interventions as cvi
+from . import analysis as cva
 
 # Specify all externally visible things this file defines
 __all__ = ['Sim']
@@ -119,11 +120,12 @@ class Sim(cvb.BaseSim):
         '''
         self.t = 0  # The current time index
         self.validate_pars() # Ensure parameters have valid values
-        self.set_seed() # Reset the random seed
+        self.set_seed() # Reset the random seed before the population is created
         self.init_results() # Create the results stucture
         self.init_people(save_pop=self.save_pop, load_pop=self.load_pop, popfile=self.popfile, **kwargs) # Create all the people (slow)
         self.validate_layer_pars() # Once the population is initialized, validate the layer parameters again
         self.init_interventions()
+        self.set_seed() # Reset the random seed again so the random number stream is consistent
         self.initialized = True
         return
 
@@ -307,7 +309,9 @@ class Sim(cvb.BaseSim):
     def load_population(self, popfile=None, **kwargs):
         '''
         Load the population dictionary from file -- typically done automatically
-        as part of sim.initialize(load_pop=True).
+        as part of sim.initialize(load_pop=True). Supports loading either saved
+        population dictionaries (popdicts, file ending .pop by convention), or
+        ready-to-go People objects (file ending .ppl by convention).
 
         Args:
             popfile (str): name of the file to load
@@ -317,15 +321,23 @@ class Sim(cvb.BaseSim):
             popfile = self.popfile
         if popfile is not None:
             filepath = sc.makefilepath(filename=popfile, **kwargs)
-            self.popdict = sc.loadobj(filepath)
-            n_actual = len(self.popdict['uid'])
+            obj = sc.loadobj(filepath)
+            if isinstance(obj, dict):
+                self.popdict = obj
+                n_actual     = len(self.popdict['uid'])
+                layer_keys   = self.popdict['layer_keys']
+            elif isinstance(obj, cvb.BasePeople):
+                self.people = obj
+                self.people.pars = self.pars # Replace the saved parameters with this simulation's
+                n_actual    = len(self.people)
+                layer_keys  = self.people.layer_keys()
             n_expected = self['pop_size']
             if n_actual != n_expected:
                 errormsg = f'Wrong number of people ({n_expected:n} requested, {n_actual:n} actual) -- please change "pop_size" to match or regenerate the file'
                 raise ValueError(errormsg)
             if self['verbose']:
                 print(f'Loaded population from {filepath}')
-            self.reset_layer_pars(force=False, layer_keys=self.popdict['layer_keys']) # Ensure that layer keys match the loaded population
+            self.reset_layer_pars(force=False, layer_keys=layer_keys) # Ensure that layer keys match the loaded population
         return
 
 
@@ -334,10 +346,10 @@ class Sim(cvb.BaseSim):
         Create the people.
 
         Args:
-            save_pop (bool): if true, save the population to popfile
-            load_pop (bool): if true, load the population from popfile
+            save_pop (bool): if true, save the population dictionary to popfile
+            load_pop (bool): if true, load the population dictionary from popfile
             popfile (str): filename to load/save the population
-            verbose (int): detail to prnt
+            verbose (int): detail to print
             kwargs (dict): passed to cv.make_people()
         '''
 
@@ -389,7 +401,8 @@ class Sim(cvb.BaseSim):
 
     def step(self):
         '''
-        Step the simulation forward in time
+        Step the simulation forward in time. Usually, the user would use sim.run()
+        rather than calling sim.step() directly.
         '''
 
         # Set the time and if we have reached the end of the simulation, then do nothing
@@ -467,7 +480,7 @@ class Sim(cvb.BaseSim):
         return
 
 
-    def run(self, do_plot=False, until=None, verbose=None, restore_pars=True, **kwargs):
+    def run(self, do_plot=False, until=None, verbose=None, restore_pars=True, reset_seed=True, **kwargs):
         '''
         Run the simulation.
 
@@ -476,6 +489,7 @@ class Sim(cvb.BaseSim):
             until (int): day to run until
             verbose (int): level of detail to print (otherwise uses self['verbose'])
             restore_pars (bool): whether to make a copy of the parameters before the run and restore it after, so runs are repeatable
+            reset_seed (bool): whether to reset the random number stream immediately before run
             kwargs (dict): passed to self.plot()
 
         Returns:
@@ -489,6 +503,8 @@ class Sim(cvb.BaseSim):
         else:
             self.validate_pars() # We always want to validate the parameters before running
             self.init_interventions() # And interventions
+            if reset_seed:
+                self.set_seed() # Ensure the random number generator is freshly initialized
         if restore_pars:
             orig_pars = sc.dcp(self.pars) # Create a copy of the parameters, to restore after the run, in case they are dynamically modified
         if verbose is None:
@@ -550,7 +566,7 @@ class Sim(cvb.BaseSim):
         self.results['cum_infections'].values += self['pop_infected']*self.rescale_vec[0] # Include initially infected people
 
         # Perform calculations on results
-        self.compute_results()
+        self.compute_results(verbose=verbose)
 
         # Convert results to a odicts/objdict to allow e.g. sim.results.diagnoses
         self.results = sc.objdict(self.results)
@@ -656,7 +672,12 @@ class Sim(cvb.BaseSim):
 
             # Calculate R_eff as the mean infectious duration times the number of new infectious divided by the number of infectious people on a given day
             raw_values = mean_inf*self.results['new_infections'].values/(self.results['n_infectious'].values+1e-6)
-            if len(raw_values) >= 3: # Can't smooth arrays shorter than this since the default smoothing kernel has length 3
+            len_raw = len(raw_values) # Calculate the number of raw values
+            if len_raw >= 3: # Can't smooth arrays shorter than this since the default smoothing kernel has length 3
+                initial_period = self['dur']['exp2inf']['par1'] + self['dur']['asym2rec']['par1'] # Approximate the duration of the seed infections for averaging
+                initial_period = int(min(len_raw, initial_period)) # Ensure we don't have too many points
+                for ind in range(initial_period): # Loop over each of the initial inds
+                    raw_values[ind] = raw_values[ind:initial_period].mean() # Replace these values with their average
                 values = sc.smooth(raw_values, smoothing)
                 values[:smoothing] = raw_values[:smoothing] # To avoid numerical effects, replace the beginning and end with the original
                 values[-smoothing:] = raw_values[-smoothing:]
@@ -817,6 +838,30 @@ class Sim(cvb.BaseSim):
         return summary
 
 
+    def make_transtree(self, output=True, *args, **kwargs):
+        '''
+        Create a TransTree (transmission tree) object, for analyzing the pattern
+        of transmissions in the simulation. See cv.TransTree() for more information.
+
+        Args:
+            output (bool): whether or not to return the TransTree; if not, store in sim.results
+            args   (list): passed to cv.TransTree()
+            kwargs (dict): passed to cv.TransTree()
+
+        **Example**::
+
+            sim = cv.Sim()
+            sim.run()
+            tt = sim.make_transtree()
+        '''
+        tt = cva.TransTree(self, *args, **kwargs)
+        if output:
+            return tt
+        else:
+            self.results.transtree = tt
+            return
+
+
     def plot(self, *args, **kwargs):
         '''
         Plot the results of a single simulation.
