@@ -8,7 +8,7 @@ import numba  as nb # For faster computations
 import numpy  as np # For numerics
 from . import defaults as cvd
 
-# What to import -- not all functions are externally available
+# What functions are externally visible -- note, this gets populated in each section below
 __all__ = []
 
 # Set dtypes
@@ -68,14 +68,14 @@ def compute_viral_load(t,     time_start, time_recovered, time_dead,  frac_time,
     return load
 
 
-@nb.njit(            (nbfloat[:], nbfloat[:], nbbool[:], nbbool[:], nbfloat,    nbfloat[:], nbbool[:], nbbool[:], nbbool[:], nbfloat,      nbfloat,     nbfloat), cache=True)
-def compute_trans_sus(rel_trans,  rel_sus,    inf,       sus,       beta_layer, viral_load, symp,      diag,      quar,      asymp_factor, diag_factor, quar_trans):
+@nb.njit(            (nbfloat[:], nbfloat[:], nbbool[:], nbbool[:], nbfloat,    nbfloat[:], nbbool[:], nbbool[:], nbbool[:], nbfloat,      nbfloat,    nbfloat), cache=True)
+def compute_trans_sus(rel_trans,  rel_sus,    inf,       sus,       beta_layer, viral_load, symp,      diag,      quar,      asymp_factor, iso_factor, quar_factor):
     ''' Calculate relative transmissibility and susceptibility '''
-    f_asymp    =  symp + ~symp * asymp_factor # Asymptomatic factor, changes e.g. [0,1] with a factor of 0.8 to [0.8,1.0]
-    f_diag     = ~diag +  diag * diag_factor # Diagnosis factor, changes e.g. [0,1] with a factor of 0.8 to [1,0.8]
-    f_quar_eff = ~quar +  quar * quar_trans # Quarantine
-    rel_trans  = rel_trans * inf * f_quar_eff * f_asymp * f_diag * beta_layer * viral_load # Recalulate transmisibility
-    rel_sus    = rel_sus   * sus * f_quar_eff # Recalulate susceptibility
+    f_asymp   =  symp + ~symp * asymp_factor # Asymptomatic factor, changes e.g. [0,1] with a factor of 0.8 to [0.8,1.0]
+    f_iso     = ~diag +  diag * iso_factor # Isolation factor, changes e.g. [0,1] with a factor of 0.2 to [1,0.2]
+    f_quar    = ~quar +  quar * quar_factor # Quarantine, changes e.g. [0,1] with a factor of 0.5 to [1,0.5]
+    rel_trans = rel_trans * inf * f_quar * f_asymp * f_iso * beta_layer * viral_load # Recalulate transmisibility
+    rel_sus   = rel_sus   * sus * f_quar # Recalulate susceptibility
     return rel_trans, rel_sus
 
 
@@ -85,13 +85,12 @@ def compute_infections(beta,     sources,  targets,   layer_betas, rel_trans,  r
     betas           = beta * layer_betas  * rel_trans[sources] * rel_sus[targets] # Calculate the raw transmission probabilities
     nonzero_inds    = betas.nonzero()[0] # Find nonzero entries
     nonzero_betas   = betas[nonzero_inds] # Remove zero entries from beta
+    nonzero_sources = sources[nonzero_inds] # Remove zero entries from the sources
     nonzero_targets = targets[nonzero_inds] # Remove zero entries from the targets
     transmissions   = (np.random.random(len(nonzero_betas)) < nonzero_betas).nonzero()[0] # Compute the actual infections!
-    edge_inds       = nonzero_inds[transmissions] # The index of the contact responsible for the transmission
+    source_inds     = nonzero_sources[transmissions]
     target_inds     = nonzero_targets[transmissions] # Filter the targets on the actual infections
-    target_inds     = np.unique(target_inds) # Ensure the targets are unique
-    return target_inds, edge_inds
-
+    return source_inds, target_inds
 
 
 #%% Sampling and seed methods
